#!perl -w

# This script copies source and test suite from pc to linux cluster
# it will convert ascii pc source files into unix eol files
# tar and zip files are created in the pc directory 

# bring in the perl module that includes copy
use File::Copy;

# base name for where we are
$basename = "c:/projects/Cloudy/oldcloudy/C06_02/";

# --------------------------------------------------------------------------
# set up path names to all targets on various machines 
# the dir above the working copies of the tsuite
#$trunk_dir = "c:/projects/cloudy/trunk/tsuite";
$trunk_dir = "$basename"."tsuite";

# the root directories for the tsuites - zip/tar files will end up here
#$unix_copy_dir    = "c:/projects/cloudy/trunk/unix/tsuite";
$unix_copy_dir    = "$basename"."unix/tsuite";
#$unix_copy_basedir    = "c:/projects/cloudy/trunk/unix";
$unix_copy_basedir    = "$basename"."unix";
#$win_copy_dir     = "c:/projects/cloudy/trunk/win/tsuite";
$win_copy_dir     = "$basename"."win/tsuite";
#$win_copy_basedir     = "c:/projects/cloudy/trunk/win;
$win_copy_basedir     = "$basename"."win";

$cluster_copy_dir = "u:/cloudy/trunk/tsuite";

# ftp site on cluster
$ftp_last = "u:/pub/gary/bleeding_edge/last";

# the subdirectories under tsuite
@subdirs=("auto","slow");

# end block - set up path names to all targets on various machines
# --------------------------------------------------------------------------

# array index for dirs below tsuite
for ($ndir=0; $ndir<2; $ndir++)
{

# --------------------------------------------------------------------------
# this block - clean out the target directories so we get fresh copies
#
# move to the pc unix tsuite dir
$dir = "$unix_copy_dir"."/"."$subdirs[$ndir]";
chdir( "$dir" ) or die " could not move to test suite directory \n";
print(" moved to tsuite unix target directory, about to delete all files\n");
# remove all files
unlink <*> ; 

# move to the win tsuite directory
$dir = "$win_copy_dir"."/"."$subdirs[$ndir]";
chdir( "$dir" ) or die " could not move to test suite directory \n";
print(" moved to tsuite win target directory, about to delete all files\n");
# remove the win tsuite files
unlink <*> ; 

# move to cluster tsuite directory
$dir = "$cluster_copy_dir"."/"."$subdirs[$ndir]";
chdir( "$dir" ) or die " could not move to cluster target directory \n";
print(" moved to cluster tsuite directory, about to delete in files\n");
# remove the old unix tsuite files - do not do * since want to keep perl files
unlink <*.in>; 
# do not remove the *.out since a job may be running

# end block - all target directories cleaned out the so we get fresh copies
# --------------------------------------------------------------------------


# --------------------------------------------------------------------------
# now copy files from trunk to copy dirs
#
# move to original tsuite directory
$dir = "$trunk_dir"."/"."$subdirs[$ndir]";
chdir( "$dir" ) or die " could not move to trunk directory \n";

# this loops over all input files in the original tsuite directory
# and copies unix eol version to subdir unix, which is now empty
# and windows eol version to subdir win/tsuite, which is empty
while( defined( $input = glob("*.in") ) )
{
	print( "$input going to " );
	$output = "$unix_copy_dir"."/"."$subdirs[$ndir]"."/"."$input";
	print("$output\n");
	# actually copy the file
	system "dos2unix < $input  > $output";
#
#       now do win version
	print( "$input going to " );
	$output = "$win_copy_dir"."/"."$subdirs[$ndir]"."/"."$input";
	print("$output\n");
	# actually execute the code
	copy( $input  , $output );
}

# now copy all html files 
while( defined( $input = glob("*.htm") ) )
{
	print( "$input going to " );
	$output = "$unix_copy_dir"."/"."$subdirs[$ndir]"."/"."$input";
	print("$output\n");
	# actually execute the code
	system "dos2unix < $input  > $output";
	$output = "$win_copy_dir"."/"."$subdirs[$ndir]"."/"."$input";
	print("$output\n");
	# actually execute the code
	copy( $input , $output );
}

# now copy all ini files 
while( defined( $input = glob("*.ini") ) )
{
	print( "$input going to " );
	$output = "$unix_copy_dir"."/"."$subdirs[$ndir]"."/"."$input";
	print("$output\n");
	# actually execute the code
	system "dos2unix < $input  > $output";
	$output = "$win_copy_dir"."/"."$subdirs[$ndir]"."/"."$input";
	print("$output\n");
	# actually execute the code
	copy( $input , $output );
}

# now copy all dat files 
while( defined( $input = glob("*.dat") ) )
{
	print( "$input going to " );
	$output = "$unix_copy_dir"."/"."$subdirs[$ndir]"."/"."$input";
	print("$output\n");
	# actually execute the code
	system "dos2unix < $input  > $output";
	$output = "$win_copy_dir"."/"."$subdirs[$ndir]"."/"."$input";
	print("$output\n");
	# actually execute the code
	copy( $input , $output );
}

# the clouds image is a binary file do a straight copy
copy( "clouds.jpg" , "$unix_copy_dir"."/"."$subdirs[$ndir]"."/"."clouds.jpg" );
# the clouds image is a binary file
copy( "clouds.jpg" , "$win_copy_dir"."/"."$subdirs[$ndir]"."/"."clouds.jpg" );

# now copy all perl scripts 
while( defined( $input = glob("*.pl") ) )
{
	print( "$input going to " );
	$output = "$unix_copy_dir"."/"."$subdirs[$ndir]"."/"."$input";
	print("$output\n");
	# actually execute the code
	system "dos2unix < $input  > $output";
	$output = "$win_copy_dir"."/"."$subdirs[$ndir]"."/"."$input";
	print("$output\n");
	# actually execute the code
	copy( $input , $output );
}

print("All tsuite files have been copied to pc unix and win subdirs\n");

# move to pc unix copy tsuite directory and copy across to cluster
$dir = "$unix_copy_dir"."/"."$subdirs[$ndir]";
chdir( "$dir" ) or die " could not move to pc unix directory \n";
# this loops over all files in the pc unix tsuite directory
# and copies unix version to subdir unix on cluster, which is now empty
while( defined( $input = glob("*") ) )
{
	print( "$input going to " );
	$output = "$cluster_copy_dir"."/"."$subdirs[$ndir]"."/"."$input";
	print("$output\n");
	# actually copy the file
	copy( $input  , $output );
}
# end copying files around
# --------------------------------------------------------------------------


# now zip up the directories we created - move into each do it from there
# so that dir name is not included

# base name of tar file
$tarfile_basename = "tsuite_"."$subdirs[$ndir]";

$dir = "$unix_copy_dir"."/"."$subdirs[$ndir]";
chdir( "$dir" ) or die " could not move to pc unix directory \n";
print(" moved to unix copy directory\n");

$tarfile = "$unix_copy_basedir"."/"."$tarfile_basename".".tar";
# remove old gzipd file if it exists
if( -e "$tarfile" )
{
   unlink("$tarfile" );
}

#   tar the files
#   NB we must do this in the directory so that we do not keep the dir structure, just names
# the cygwin tar chocked on the fully resolved tarfile name 
#system "tar -cf $tarfile * ";
system "C:\\u\\mks\\mksnt\\tar_mks.exe -cf $tarfile * ";
print( "about to gzip $tarfile\n" );
# remove old gzipd file if it exists
if( -e "$tarfile".".gz" )
{
   unlink("$tarfile".".gz" );
}
system "gzip $tarfile ";

# copy to the ftp site
copy( "$tarfile".".gz" , $ftp_last );

# how go to win home and zip the win source dir
$dir = "$win_copy_dir"."/"."$subdirs[$ndir]";
chdir( "$dir" ) or die " could not move to pc win directory \n";
print(" moved to win copy directory\n");

# remove old gzipd file if it exists
$tarfile = "$win_copy_basedir"."/"."$tarfile_basename".".zip";
if( -e "$tarfile" )
{
   unlink("$tarfile" );
}

# create zip file
#system "c:\\u\\wzzip $tarfile  ";
system "wzzip $tarfile  ";

# finally copy the newly created files to the ftp site
copy( "$tarfile" , $ftp_last );

print("\ndone\n");

}
